@@ -5,9 +5,9 @@ use strict;
 use warnings;
 ##use Mail::Milter::Authentication::Pragmas;
 # ABSTRACT: Common configuration handling
-our $VERSION = '2.20200331.1'; # VERSION
+our $VERSION = '2.20200420.1'; # VERSION
 use English;
-use JSON;
+use JSON::XS;
 use TOML;
 use Module::Load;
 use Module::Loaded;
@@ -111,7 +111,7 @@ sub load_file {
           || die "Error parsing config file $file";
     }
     else {
-        my $json = JSON->new();
+        my $json = JSON::XS->new();
         $json->relaxed(1);
         $data = $json->decode($text)
           || die "Error parsing config file $file";
@@ -210,7 +210,7 @@ Mail::Milter::Authentication::Config - Load config files for Authentication Milt
 
 =head1 VERSION
 
-version 2.20200331.1
+version 2.20200420.1
 
 =head1 SYNOPSIS
 
