@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Mail::Milter::Authentication::Pragmas;
 # ABSTRACT: Class for metrics generation
-our $VERSION = '2.20200331.1'; # VERSION
+our $VERSION = '2.20200420.1'; # VERSION
 use Mail::Milter::Authentication::HTDocs;
 use Mail::Milter::Authentication::Metric::Grafana;
 use File::Temp;
@@ -404,7 +404,7 @@ sub child_handler {
             print $socket "HTTP/1.0 200 OK\n";
             print $socket "Content-Type: text/plain\n";
             print $socket "\n";
-            my $json = JSON->new();
+            my $json = JSON::XS->new();
             $json->canonical();
             $json->pretty();
             print $socket $json->encode( $config );;
@@ -457,7 +457,7 @@ Mail::Milter::Authentication::Metric - Class for metrics generation
 
 =head1 VERSION
 
-version 2.20200331.1
+version 2.20200420.1
 
 =head1 DESCRIPTION
 
