@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Mail::Milter::Authentication::Pragmas;
 # ABSTRACT: Class for Grafana dashboards
-our $VERSION = '2.20200331.1'; # VERSION
+our $VERSION = '2.20200420.1'; # VERSION
 
 sub get_json {
     my ( $self, $file ) = @_;
@@ -48,7 +48,7 @@ sub get_dashboard {
         }
     }
 
-    my $J = JSON->new();
+    my $J = JSON::XS->new();
     $J->pretty();
     $J->canonical();
 
@@ -73,7 +73,7 @@ Mail::Milter::Authentication::Metric::Grafana - Class for Grafana dashboards
 
 =head1 VERSION
 
-version 2.20200331.1
+version 2.20200420.1
 
 =head1 DESCRIPTION
 
