@@ -3,7 +3,7 @@ use 5.20.0;
 use strict;
 use warnings;
 # ABSTRACT: Setup system wide pragmas
-our $VERSION = '2.20200331.1'; # VERSION
+our $VERSION = '2.20200420.1'; # VERSION
 use base 'Exporter';
 require feature;
 use open ':std', ':encoding(UTF-8)';
@@ -14,7 +14,7 @@ use Mail::Milter::Authentication::Config;
 use Carp;
 use Clone;
 use English;
-use JSON;
+use JSON::XS;
 use Module::Load;
 use Module::Loaded;
 use Mail::AuthenticationResults 1.20200108;
@@ -37,7 +37,7 @@ sub import {
   Carp->import::into(scalar caller);
   Clone->import::into(scalar caller,qw{ clone });
   English->import::into(scalar caller);
-  JSON->import::into(scalar caller);
+  JSON::XS->import::into(scalar caller);
   Module::Load->import::into(scalar caller);
   Module::Loaded->import::into(scalar caller);
 }
@@ -56,7 +56,7 @@ Mail::Milter::Authentication::Pragmas - Setup system wide pragmas
 
 =head1 VERSION
 
-version 2.20200331.1
+version 2.20200420.1
 
 =head1 AUTHOR
 
